# WSO-UEM-Py
[![Build Status](https://travis-ci.org/rorymurdock/WSO-UEM-Py.svg?branch=master)](https://travis-ci.org/rorymurdock/WSO-UEM-Py) 
[![Maintainability](https://api.codeclimate.com/v1/badges/3be7fc89238b38fc0031/maintainability)](https://codeclimate.com/github/rorymurdock/WSO-UEM-Py/maintainability)
[![Documentation Status](https://readthedocs.org/projects/wso-uem-py/badge/?version=latest)](https://wso-uem-py.readthedocs.io/en/latest/?badge=latest)
[![Coverage Status](https://coveralls.io/repos/github/rorymurdock/WSO-UEM-Py/badge.svg?branch=master)](https://coveralls.io/github/rorymurdock/WSO-UEM-Py?branch=master)
[![Requirements Status](https://requires.io/github/rorymurdock/WSO-UEM-Py/requirements.svg?branch=UEM-API)](https://requires.io/github/rorymurdock/WSO-UEM-Py/requirements/?branch=UEM-API)

A Python framework for interacting with WSO UEM
